@@ -148,7 +148,7 @@ impl GeneralReadout for NetBSDGeneralReadout {
             )));
         }
 
-        if let Ok(val) = backlight.parse::<usize>() {
+        if let Ok(val) = pop_newline(backlight).parse::<usize>() {
             return Ok(val);
         }
 
@@ -208,6 +208,10 @@ impl GeneralReadout for NetBSDGeneralReadout {
         crate::shared::desktop_environment()
     }
 
+    fn session(&self) -> Result<String, ReadoutError> {
+        crate::shared::session()
+    }
+
     fn window_manager(&self) -> Result<String, ReadoutError> {
         crate::shared::window_manager()
     }
