@@ -424,6 +424,14 @@ pub trait GeneralReadout {
         Err(STANDARD_NO_IMPL.clone())
     }
 
+    
+    /// This function should return the type of session that's in use.
+    ///
+    /// _e.g._ `Wayland`
+    fn session(&self) -> Result<String, ReadoutError> {
+        Err(STANDARD_NO_IMPL.clone())
+    }
+
     /// This function should return the name of the used window manager.
     ///
     /// _e.g._ `KWin`
